/* Code for Barrett, Christopher B.,	*/
/* Marc F. Bellemare, and Janet Y. Hou,	*/
/* "Reconsidering Conventional		*/
/* Explanations of the Inverse Size-	*/
/* Productivity Relationship,"		*/
/* forthcoming, World Development.	*/

/* Code Author: Marc F. Bellemare	*/
/* Assistant Professor of Public Policy	*/
/* and Economics, Duke University	*/

/* This Version: July 13, 2009		*/



clear
drop _all

set mem 512m
set matsize 1000

use "C:\BellemareBarrettHouInverseRelationship.dta"

log using "C:\BellemareBarrettHouInverseRelationship.smcl", replace



/* Production Function Approach		*/

reg ln_yield ln_area ln_adult ln_child ln_hired ln_help ln_traction hhsize depr single_male single_female dam spring rain ln_tot_area ln_land_val v2 v3 v4 v5 v6 v7 v9 v11 v19 v20 v21 v22 v23 v24 v32 v33 v37 v40 v41 v42 v43  v44 v70 v72 if yield>0


xtreg ln_yield ln_area ln_adult ln_child ln_hired ln_help ln_traction hhsize depr single_male single_female dam spring rain ln_tot_area ln_land_val v2 v3 v4 v5 v6 v7 v9 v11 v19 v20 v21 v22 v23 v24 v32 v33 v37 v40 v41 v42 v43  v44 v70 v72 if yield>0, fe i(hhid)

egen ybar = mean(ln_yield)
gen y2 = (ln_yield - ybar)^2
predict resid, e
gen e2 = resid^2
drop resid
egen sse = sum(e2)
egen sst = sum(y2)
gen r2_hh = 1 - sse/sst
drop sse sst y2 e2 ybar


set seed 123456789

reg ln_yield ln_area ln_adult ln_child ln_hired ln_help ln_traction hhsize depr single_male single_female dam spring rain ln_tot_area ln_land_val v2 v3 v4 v5 v6 v7 v9 v11 v19 v20 v21 v22 v23 v24 v32 v33 v37 v40 v41 v42 v43  v44 v70 v72 ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand if yield>0, vce(bootstrap, reps(500))

test ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand


set seed 123456789

xtreg ln_yield ln_area ln_adult ln_child ln_hired ln_help ln_traction hhsize depr single_male single_female dam spring rain ln_tot_area ln_land_val v2 v3 v4 v5 v6 v7 v9 v11 v19 v20 v21 v22 v23 v24 v32 v33 v37 v40 v41 v42 v43  v44 v70 v72 ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand if yield>0, fe i(hhid) vce(bootstrap, reps(500))

test ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand

test ln_area ln_adult ln_child ln_hired ln_help ln_traction dam spring rain ln_land_val ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand

egen ybar = mean(ln_yield)
gen y2 = (ln_yield - ybar)^2
predict resid, e
gen e2 = resid^2
drop resid
egen sse = sum(e2)
egen sst = sum(y2)
gen r2_hhsq = 1 - sse/sst
drop sse sst y2 e2 ybar



/* Yield Approach		 	*/

reg ln_yield ln_area ln_tot_area ln_land_val hhsize depr single_male single_female dam spring rain v2 v3 v4 v5 v6 v7 v9 v11 v19 v20 v21 v22 v23 v24 v32 v33 v37 v40 v41 v42 v43 v44 v70 v72 if (yield>0 & ln_land_val~=.)


xtreg ln_yield ln_area ln_tot_area ln_land_val hhsize depr single_male single_female dam spring rain v2 v3 v4 v5 v6 v7 v9 v11 v19 v20 v21 v22 v23 v24 v32 v33 v37 v40 v41 v42 v43  v44 v70 v72 if yield>0, fe i(hhid)

test ln_area ln_land_val dam spring rain

egen ybar = mean(ln_yield)
gen y2 = (ln_yield - ybar)^2
predict resid, e
gen e2 = resid^2
drop resid
egen sse = sum(e2)
egen sst = sum(y2)
gen r2_yhh = 1 - sse/sst
drop sse sst y2 e2 ybar


set seed 123456789

reg ln_yield ln_area ln_tot_area ln_land_val hhsize depr single_male single_female dam spring rain v2 v3 v4 v5 v6 v7 v9 v11 v19 v20 v21 v22 v23 v24 v32 v33 v37 v40 v41 v42 v43  v44 v70 v72 ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand if yield>0, vce(bootstrap, reps(500))

test ln_c ln_n ln_ph ln_pot ln_clay


set seed 123456789

xtreg ln_yield ln_area ln_tot_area ln_land_val hhsize depr single_male single_female dam spring rain v2 v3 v4 v5 v6 v7 v9 v11 v19 v20 v21 v22 v23 v24 v32 v33 v37 v40 v41 v42 v43  v44 v70 v72 ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand if yield>0, fe i(hhid) vce(bootstrap, reps(500))

predict yhat

test ln_c ln_n ln_ph ln_pot ln_clay ln_silt

test ln_area ln_land_val dam spring rain ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand

egen ybar = mean(ln_yield)
gen y2 = (ln_yield - ybar)^2
predict resid, e
gen e2 = resid^2
drop resid
egen sse = sum(e2)
egen sst = sum(y2)
gen r2_yhhsq = 1 - sse/sst
drop sse sst y2 e2 ybar


drop if ln_land_val==. | ln_tot_area==.


sum yield area adult child hired help traction hhsize depr single_male single_female total_area dam spring rain land_val_are total_area chat nhat phhat pothat clayhat silthat sandhat if yhat~=.


pwcorr yield area if yhat~=. & yield>0, star(.01)

pwcorr yield area if yhat~=. & yield>0, star(.05)

pwcorr yield area if yhat~=. & yield>0, star(.10)

pwcorr ln_yield ln_area if yhat~=. & yield>0, star(.01)

pwcorr ln_yield ln_area if yhat~=. & yield>0, star(.05)

pwcorr ln_yield ln_area if yhat~=. & yield>0, star(.10)


drop yhat



/* Hedonic Regressions			*/

set seed 123456789

reg ln_land_val ln_area ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand dam spring rain v2 v3 v4 v5 v6 v7 v9 v11 v19 v20 v21 v22 v23 v24 v32 v33 v37 v40 v41 v42 v43 v44 v70 v72 if yield>0, vce(bootstrap, reps(500))

test ln_c ln_n ln_ph ln_pot ln_clay ln_silt


set seed 123456789

xtreg ln_land_val ln_area ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand dam spring rain v2 v3 v4 v5 v6 v7 v9 v11 v19 v20 v21 v22 v23 v24 v32 v33 v37 v40 v41 v42 v43 v44 v70 v72 if yield>0, fe i(hhid) vce(bootstrap, reps(500))

test ln_c ln_n ln_ph ln_pot ln_clay ln_silt

test ln_area ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand dam spring rain 

predict yhat

egen ybar = mean(ln_yield)
gen y2 = (ln_yield - ybar)^2
predict resid, e
gen e2 = resid^2
drop resid
egen sse = sum(e2)
egen sst = sum(y2)
gen r2_hedo = 1 - sse/sst
drop sse sst y2 e2 ybar


log close

